﻿using Infragistics.DragDrop;
using Infragistics.Controls.Menus;
using System.Windows;

namespace GroupEditorPrototype
{
    public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();
			Loaded += OnLoaded;

			DataContext = _vm;
		}

		private void OnLoaded(object sender, RoutedEventArgs e)
		{
			_vm.Initialize();
		}

		private void OnAssetDragDrop(object sender, TreeDropEventArgs e)
		{
			if ((e.DragDropEventArgs.DropTarget as XamDataTreeNodeControl) != null &&
				(e.DragDropEventArgs.DragSource as XamDataTreeNodeControl) != null)
			{
				var dropNode = (e.DragDropEventArgs.DropTarget as XamDataTreeNodeControl).Node;
				var dragNode = (e.DragDropEventArgs.DragSource as XamDataTreeNodeControl).Node;

				if (dropNode != null && dragNode != null && !(dropNode.Data is Schema))
				{
					var dropNodeName = (dropNode.Data as GroupingItem).Name;
					var dragNodeName = (dragNode.Data as GroupingItem).Name;

					if (!dragNode.NodeLayout.Tree.Equals(dropNode.Control.Node.NodeLayout.Tree))
					{
						if (dragNode.Data is Device)
						{							
							var newDevice = new XamDataTreeNode(
								dropNode.Index + 1,
								dropNode.Manager,
								new Device { Name = dragNodeName, ParentGroup = dropNodeName},
								false,
								dropNode.NodeLayout);
							dropNode.Nodes.Add(newDevice);

							e.Handled = true;
                        }
						else if (dragNode.Data is AssetNode)
						{
							var newNode = new XamDataTreeNode(
								dropNode.Index + 1,
								dropNode.Manager,
								new SchemaNode { Name = dragNodeName, ParentGroup = dropNodeName},
								false,
								dropNode.NodeLayout);
							dropNode.Nodes.Add(newNode);

							e.Handled = true;
						}
					}
				}
                else
                {
					e.Handled = true;
                }
			}
		}

		private void OnSchemasTreeDraggingStart(object sender, DragDropStartEventArgs e)
        {
			if (e.DragSource != null)
			{
				var dragSource = DragDropManager.GetDragSource(e.DragSource);
				//dragSource.DragEnter += OnSchemasTreeDragEnter;
				//dragSource.DragLeave += OnSchemasTreeDragLeave;
				dragSource.Drop += OnSchemasTreeDrop;
			}
		}

        private void OnSchemasTreeDrop(object sender, DropEventArgs e)
        {
			if ((e.DropTarget as XamDataTreeNodeControl) != null && (e.DragSource as XamDataTreeNodeControl) != null)
			{
				var sourceNode = (e.DragSource as XamDataTreeNodeControl).Node;
				var targetNode = (e.DropTarget as XamDataTreeNodeControl).Node;
				if (targetNode.Data is Group && sourceNode.Data is Group)
				{
					var copiedGroup = new XamDataTreeNode(
						targetNode.Index + 1,
						targetNode.Manager,
						new Group { Name = (sourceNode.Data as Group).Name, Children = (sourceNode.Data as Group).Children, ParentGroup = (targetNode.Data as Group).ParentGroup },
						false,
						targetNode.NodeLayout);
					targetNode.Nodes.Add(copiedGroup);
					targetNode.IsExpanded = true;
				}
			}
		}

        private void OnSchemasTreeDragEnter(object sender, DragDropCancelEventArgs e)
        {
			if ((e.DropTarget as XamDataTreeNodeControl) != null && (e.DragSource as XamDataTreeNodeControl) != null)
			{

            }
		}

		private void OnSchemasTreeDragLeave(object sender, DragDropEventArgs e)
        {
			if ((e.DropTarget as XamDataTreeNodeControl) != null && (e.DragSource as XamDataTreeNodeControl) != null)
			{
			}
		}

		private void OnSchemasTreeDragEnd(object sender, DragDropEventArgs e)
        {
			var dragSource = DragDropManager.GetDragSource(e.DragSource);
			//dragSource.DragEnter -= OnSchemasTreeDragEnter;
			//dragSource.DragLeave -= OnSchemasTreeDragLeave;
			dragSource.Drop -= OnSchemasTreeDrop;
		}
    }
}
